Daily Movement

### Input Payments:

#### Sales

Code | Sales Person | Client | Value
01000 | SalesPerson | Not Specified | $100.00
| Card Credit | 1234 - PRO1 - MAQ1 | $100.00 (1x)
| Card Debit | 1234 - PRO1 - MAQ1 | $100.00 (1x)
23456 | SalesPerson | Not Specified | $20.00
| Money |  | $20.00 (1x)

#### Lonely Payments

Code | Method | Description | Payment Value
01001 | Money | Test receivable account | $100.00

### Output Payments:

#### Purchases

Code | Status | Responsible | Branch | Notes | Supplier | Purchase | Method | Details | Value
12345 | Quoting | Administrator | Moda Stoq |  | Supplier | - | - | - | $ 0.00
|  |  |  |  |  | 01002 | Money |  | $100.00

#### Lonely Payments

Code | Method | Description | Payment Value
01004 | Money | 1/1 Money for | $100.00

#### Return Sales

Code | Sales Person | Client | Return Date | Sale Value
23456 | SalesPerson | Not Specified | 01/01/13 | $20.00
Code | Method | Description | Payment Value
01003 | Money | Money returned for sale 23456 | $20.00

### Summary:

#### Per Payment Method

Payment Method | Income Total | Outgoing Total
Card | $200.00 | $ 0.00
Money | $120.00 | $220.00
Total: | $320.00 | $220.00

#### Per Card Provider

Provider Name | Income Total
PRO1 Credit | $100.00
PRO1 Debit | $100.00
Total: | $200.00

### Observations:

Signature Verified by